@@ -1,15 +1,9 @@
-#! python3.8 -u
-#  -*- coding: utf-8 -*-
-
-##############################
-## Project PyCTLib
-## Package torchplus.nn
-##############################
-
 import torchplus
 import torch
+from torch._C import _disabled_torch_function_impl
 from collections import OrderedDict
 
+
 class Parameter(torchplus.Tensor):
     r"""A kind of Tensor that is to be considered a module parameter.
 
@@ -27,20 +21,16 @@ class Parameter(torchplus.Tensor):
         requires_grad (bool, optional): if the parameter requires gradient. See
             :ref:`excluding-subgraphs` for more details. Default: `True`
     """
-
     def __new__(cls, data=None, requires_grad=True):
         if data is None:
             data = torchplus.Tensor()
-        assert isinstance(data, torch.Tensor)
-        self = torchplus.Tensor._make_subclass(cls, data.data, auto_device=False, requires_grad=requires_grad)
-        # self._batch_dimension = data._batch_dimension
-        return self
+        return torchplus.Tensor._make_subclass(cls, data, requires_grad=requires_grad, auto_device=False)
 
     def __deepcopy__(self, memo):
         if id(self) in memo:
             return memo[id(self)]
         else:
-            result = type(self)(self.data.clone(memory_format=torch.preserve_format), self.auto_device, self.requires_grad, self.batch_dimension)
+            result = type(self)(self.data.clone(memory_format=torch.preserve_format), self.requires_grad)
             memo[id(self)] = result
             return result
 
@@ -53,3 +43,5 @@ class Parameter(torchplus.Tensor):
             torch._utils._rebuild_parameter,
             (self.data, self.requires_grad, OrderedDict())
         )
+
+    __torch_function__ = _disabled_torch_function_impl
